@@ -3,6 +3,7 @@ xUML_class_diagram.py – Generates an xuml diagram for an xuml model using the
 """
 
 import sys
+import logging
 from pathlib import Path
 from flatland.flatland_exceptions import FlatlandIOException, MultipleFloatsInSameBranch
 from flatland.input.model_parser import ModelParser
@@ -25,28 +26,32 @@ BranchLeaves = namedtuple('BranchLeaves', 'leaf_stems local_graft next_graft flo
 
 class XumlClassDiagram:
 
-    def __init__(self, xuml_model_path: Path, flatland_layout_path: Path, diagram_file_path: Path):
+    def __init__(self, xuml_model_path: Path, flatland_layout_path: Path, diagram_file_path: Path, rebuild=False):
         """Constructor"""
+        self.logger = logging.getLogger(__name__)
         self.xuml_model_path = xuml_model_path
         self.flatland_layout_path = flatland_layout_path
         self.diagram_file_path = diagram_file_path
+        self.rebuild = rebuild
 
+        self.logger.info("Parsing the model")
         # Parse the model
         try:
-            self.model = ModelParser(model_file_path=self.xuml_model_path, debug=True)
+            self.model = ModelParser(model_file_path=self.xuml_model_path, debug=False)
         except FlatlandIOException as e:
             sys.exit(e)
         self.subsys = self.model.parse()
 
+        self.logger.info("Parsing the layout")
         # Parse the layout
         try:
-            self.layout = LayoutParser(layout_file_path=self.flatland_layout_path, debug=True)
+            self.layout = LayoutParser(layout_file_path=self.flatland_layout_path, debug=False)
         except FlatlandIOException as e:
             sys.exit(e)
         self.layout = self.layout.parse()
 
         # Load the flatland database
-        self.db = FlatlandDB()
+        self.db = FlatlandDB(rebuild=self.rebuild)
 
         # Draw the blank canvas of the appropriate size, diagram type and presentation style
         self.flatland_canvas = self.create_canvas()
@@ -161,7 +166,6 @@ class XumlClassDiagram:
                 tertiary_stem=a_stem,
                 name=rnum_data
             )
-            print("Straight connector")
         else:
             BendingBinaryConnector(
                 diagram=self.flatland_canvas.Diagram,
